@@ -1200,7 +1200,7 @@ class VectorsInternalSplitedDataReader:
         result = X_result, y_result, ids_result
         return result
 
-class LargeFileWriter:
+class HumlLargeFileWriter:
     def __init__(self, directory_path):
         #self.logger = logger
         self.directory_path = directory_path
